@@ -7,7 +7,7 @@ from mmap_ninja.ragged import RaggedMmap
 from mmap_ninja.string import StringsMmap
 
 
-def list_of_dicts_to_dict_of_lists(dicts: List[Dict], mode: str, verbose=False) -> Dict[str, List]:
+def _list_of_dicts_to_dict_of_lists(dicts: List[Dict], mode: str, verbose=False) -> Dict[str, List]:
     task_values = defaultdict(list)
     sequence = dicts
     if verbose:
@@ -24,9 +24,12 @@ def list_of_dicts_to_dict_of_lists(dicts: List[Dict], mode: str, verbose=False)
     return dict(task_values)
 
 
-def load_dir_as_dict(out_dir, wrapper_fn_dict, subset):
+def _load_dir_as_dict(out_dir, wrapper_fn_dict, subset):
     dct = {}
-    for path in out_dir.iterdir():
+    children = sorted(list(out_dir.iterdir()))
+    for path in children:
+        if not path.is_dir():
+            continue
         key = path.name
         if subset and key not in subset:
             continue
@@ -84,3 +87,8 @@ def _create_mmap_for_key(out_dir, key, values, verbose):
         _create_ragged_mmap_for_key(out_dir, key, values, verbose)
     elif len(shapes) == 1:
         _create_numpy_mmap_for_key(out_dir, key, values, verbose)
+
+
+def generate_batches(batch_fn, data, batch_size):
+    for i in range(0, len(data), batch_size):
+        yield batch_fn(data[i: i + batch_size])
