@@ -8,7 +8,7 @@ from mmap_ninja import numpy as np_ninja
 from mmap_ninja.base import Wrapped, from_generator_base
 from mmap_ninja.string import StringsMmap
 
-from mmap_ninja_dataframe.base import _create_mmap_for_key, load_dir_as_dict
+from mmap_ninja_dataframe.base import _create_mmap_for_key, _load_dir_as_dict
 
 
 def _get_all_keys(dicts):
@@ -58,7 +58,7 @@ class SparseDataFrameMmap:
         self._out_dir = out_dir
         self._wrapper_fn_dict = {} if wrapper_fn_dict is None else wrapper_fn_dict
         self._subset = subset
-        self._data = load_dir_as_dict(self._out_dir, self._wrapper_fn_dict, subset=self._subset)
+        self._data = _load_dir_as_dict(self._out_dir, self._wrapper_fn_dict, subset=self._subset)
         self._positions = Wrapped(StringsMmap(out_dir / '_positions'), wrapper_fn=ast.literal_eval)
         self._columns = [k for k in self._data if not k.startswith('_')]
         self._target_keys = set(target_keys) if target_keys else None
@@ -101,7 +101,7 @@ class SparseDataFrameMmap:
                 np_ninja.extend(mmap, np.asarray(new_value))
             else:
                 mmap.extend(new_value)
-        self._data = load_dir_as_dict(self._out_dir, self._wrapper_fn_dict, subset=self._subset)
+        self._data = _load_dir_as_dict(self._out_dir, self._wrapper_fn_dict, subset=self._subset)
         self._positions = Wrapped(StringsMmap(self._out_dir / '_positions'), wrapper_fn=ast.literal_eval)
 
     @classmethod
